==> iTop-3.2.0-2-14758.zip: web/datamodels/2.x/itop-problem-mgmt/dictionaries/fr.dict.itop-problem-mgmt.php <==
<?php
/**
 * Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * 
 */
/**
 *
 */
Dict::Add('FR FR', 'French', 'Français', [
	'Class:Problem' => 'Problème',
	'Class:Problem+' => '',
	'Class:Problem/Attribute:assignment_date' => 'Date d\'assignation',
	'Class:Problem/Attribute:assignment_date+' => '',
	'Class:Problem/Attribute:impact' => 'Impact',
	'Class:Problem/Attribute:impact+' => 'Impact indique la séverité du problème, souvent estimé par le nombre de personnes impactées',
	'Class:Problem/Attribute:impact/Value:1' => 'Un département',
	'Class:Problem/Attribute:impact/Value:1+' => '',
	'Class:Problem/Attribute:impact/Value:2' => 'Un service',
	'Class:Problem/Attribute:impact/Value:2+' => '',
	'Class:Problem/Attribute:impact/Value:3' => 'Une personne',
	'Class:Problem/Attribute:impact/Value:3+' => '',
	'Class:Problem/Attribute:knownerrors_list' => 'Erreurs connues',
	'Class:Problem/Attribute:knownerrors_list+' => 'Toutes les erreurs connues liées à ce problème',
	'Class:Problem/Attribute:knownerrors_list/UI:Links:Create:Button+' => 'Créer une %4$s',
	'Class:Problem/Attribute:knownerrors_list/UI:Links:Create:Modal:Title' => 'Ajouter une %4$s à %2$s',
	'Class:Problem/Attribute:knownerrors_list/UI:Links:Delete:Button+' => 'Supprimer cette %4$s',
	'Class:Problem/Attribute:knownerrors_list/UI:Links:Delete:Modal:Title' => 'Supprimer une %4$s',
	'Class:Problem/Attribute:knownerrors_list/UI:Links:Remove:Button+' => 'Retirer cette %4$s',
	'Class:Problem/Attribute:knownerrors_list/UI:Links:Remove:Modal:Title' => 'Retirer cette %4$s de son %1$s',
	'Class:Problem/Attribute:priority' => 'Priorité',
	'Class:Problem/Attribute:priority+' => 'Ordre dans lequel les problèmes doivent être traités',
	'Class:Problem/Attribute:priority/Value:1' => 'Critique',
	'Class:Problem/Attribute:priority/Value:1+' => '',
	'Class:Problem/Attribute:priority/Value:2' => 'Haute',
	'Class:Problem/Attribute:priority/Value:2+' => '',
	'Class:Problem/Attribute:priority/Value:3' => 'Moyenne',
	'Class:Problem/Attribute:priority/Value:3+' => '',
	'Class:Problem/Attribute:priority/Value:4' => 'Basse',
	'Class:Problem/Attribute:priority/Value:4+' => '',
	'Class:Problem/Attribute:product' => 'Produit',
	'Class:Problem/Attribute:product+' => '',
	'Class:Problem/Attribute:related_change_id' => 'Changement relatif',
	'Class:Problem/Attribute:related_change_id+' => '',
	'Class:Problem/Attribute:related_change_ref' => 'Ref Changement relatif',
	'Class:Problem/Attribute:related_change_ref+' => '',
	'Class:Problem/Attribute:related_incident_list' => 'Incidents liés',
	'Class:Problem/Attribute:related_incident_list+' => 'Tous les incidents liés à ce problème',
	'Class:Problem/Attribute:related_incident_list/UI:Links:Create:Button+' => 'Créer un %4$s',
	'Class:Problem/Attribute:related_incident_list/UI:Links:Create:Modal:Title' => 'Ajouter un %4$s à %2$s',
	'Class:Problem/Attribute:related_incident_list/UI:Links:Delete:Button+' => 'Supprimer ce %4$s',
	'Class:Problem/Attribute:related_incident_list/UI:Links:Delete:Modal:Title' => 'Supprimer un %4$s',
	'Class:Problem/Attribute:related_incident_list/UI:Links:Remove:Button+' => 'Retirer ce %4$s',
	'Class:Problem/Attribute:related_incident_list/UI:Links:Remove:Modal:Title' => 'Retirer ce %4$s de son %1$s',
	'Class:Problem/Attribute:related_request_list' => 'Requêtes liées',
	'Class:Problem/Attribute:related_request_list+' => 'Toutes les requêtes liées à ce problème',
	'Class:Problem/Attribute:related_request_list/UI:Links:Create:Button+' => 'Créer une %4$s',
	'Class:Problem/Attribute:related_request_list/UI:Links:Create:Modal:Title' => 'Ajouter une %4$s à %2$s',
	'Class:Problem/Attribute:related_request_list/UI:Links:Delete:Button+' => 'Supprimer cette %4$s',
	'Class:Problem/Attribute:related_request_list/UI:Links:Delete:Modal:Title' => 'Supprimer une %4$s',
	'Class:Problem/Attribute:related_request_list/UI:Links:Remove:Button+' => 'Retirer cette %4$s',
	'Class:Problem/Attribute:related_request_list/UI:Links:Remove:Modal:Title' => 'Retirer cette %4$s de son %1$s',
	'Class:Problem/Attribute:resolution_date' => 'Date de résolution',
	'Class:Problem/Attribute:resolution_date+' => '',
	'Class:Problem/Attribute:service_id' => 'Service',
	'Class:Problem/Attribute:service_id+' => '',
	'Class:Problem/Attribute:service_name' => 'Nom du service',
	'Class:Problem/Attribute:service_name+' => '',
	'Class:Problem/Attribute:servicesubcategory_id' => 'Sous catégorie de service',
	'Class:Problem/Attribute:servicesubcategory_id+' => '',
	'Class:Problem/Attribute:servicesubcategory_name' => 'Nom sous catégorie de service',
	'Class:Problem/Attribute:servicesubcategory_name+' => '',
	'Class:Problem/Attribute:status' => 'Etat',
	'Class:Problem/Attribute:status+' => '',
	'Class:Problem/Attribute:status/Value:assigned' => 'Assigné',
	'Class:Problem/Attribute:status/Value:assigned+' => '',
	'Class:Problem/Attribute:status/Value:closed' => 'Fermé',
	'Class:Problem/Attribute:status/Value:closed+' => '',
	'Class:Problem/Attribute:status/Value:new' => 'Nouveau',
	'Class:Problem/Attribute:status/Value:new+' => '',
	'Class:Problem/Attribute:status/Value:resolved' => 'Résolu',
	'Class:Problem/Attribute:status/Value:resolved+' => '',
	'Class:Problem/Attribute:urgency' => 'Urgence',
	'Class:Problem/Attribute:urgency+' => 'Avec quelle célérité le probléme doit être traité',
	'Class:Problem/Attribute:urgency/Value:1' => 'Critique',
	'Class:Problem/Attribute:urgency/Value:1+' => '',
	'Class:Problem/Attribute:urgency/Value:2' => 'Haute',
	'Class:Problem/Attribute:urgency/Value:2+' => '',
	'Class:Problem/Attribute:urgency/Value:3' => 'Moyenne',
	'Class:Problem/Attribute:urgency/Value:3+' => '',
	'Class:Problem/Attribute:urgency/Value:4' => 'Basse',
	'Class:Problem/Attribute:urgency/Value:4+' => '',
	'Class:Problem/Stimulus:ev_assign' => 'Assigner',
	'Class:Problem/Stimulus:ev_assign+' => '',
	'Class:Problem/Stimulus:ev_close' => 'Fermer',
	'Class:Problem/Stimulus:ev_close+' => '',
	'Class:Problem/Stimulus:ev_reassign' => 'Réaassigner',
	'Class:Problem/Stimulus:ev_reassign+' => '',
	'Class:Problem/Stimulus:ev_resolve' => 'Résoudre',
	'Class:Problem/Stimulus:ev_resolve+' => '',
	'Menu:NewProblem' => 'Nouveau problème',
	'Menu:NewProblem+' => '',
	'Menu:Problem:MyProblems' => 'Mes problèmes',
	'Menu:Problem:MyProblems+' => '',
	'Menu:Problem:OpenProblems' => 'Problèmes ouverts',
	'Menu:Problem:OpenProblems+' => '',
	'Menu:Problem:Overview' => 'Vue d\'ensemble',
	'Menu:Problem:Overview+' => '',
	'Menu:Problem:Shortcuts' => 'Raccourcis',
	'Menu:ProblemManagement' => 'Gestion des problèmes',
	'Menu:ProblemManagement+' => '',
	'Menu:SearchProblems' => 'Rechercher des problèmes',
	'Menu:SearchProblems+' => '',
	'UI-ProblemManagementOverview-ProblemByPriority' => 'Problèmes par priorité',
	'UI-ProblemManagementOverview-ProblemByPriority+' => '',
	'UI-ProblemManagementOverview-ProblemByService' => 'Problèmes par service',
	'UI-ProblemManagementOverview-ProblemByService+' => '',
	'UI-ProblemManagementOverview-ProblemUnassigned' => 'Problèmes non affectés à un agent',
	'UI-ProblemManagementOverview-ProblemUnassigned+' => '',
	'UI:ProblemMgmtMenuOverview:Title' => 'Tableau de bord de la Gestion des Problèmes',
	'UI:ProblemMgmtMenuOverview:Title+' => 'Tableau de bord de la Gestion des Problèmes',
]);

==> iTop-3.2.2-1-17851.zip: web/datamodels/2.x/itop-problem-mgmt/dictionaries/fr.dict.itop-problem-mgmt.php <==
<?php
/**
 * Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * 
 */
/**
 *
 */
Dict::Add('FR FR', 'French', 'Français', array(
	'Menu:ProblemManagement' => 'Gestion des problèmes',
	'Menu:ProblemManagement+' => '',
	'Menu:Problem:Overview' => 'Vue d\'ensemble',
	'Menu:Problem:Overview+' => '',
	'Menu:NewProblem' => 'Nouveau problème',
	'Menu:NewProblem+' => '',
	'Menu:SearchProblems' => 'Rechercher des problèmes',
	'Menu:SearchProblems+' => '',
	'Menu:Problem:Shortcuts' => 'Raccourcis',
	'Menu:Problem:MyProblems' => 'Mes problèmes',
	'Menu:Problem:MyProblems+' => '',
	'Menu:Problem:OpenProblems' => 'Problèmes ouverts',
	'Menu:Problem:OpenProblems+' => '',
	'UI-ProblemManagementOverview-ProblemByService' => 'Problèmes par service',
	'UI-ProblemManagementOverview-ProblemByService+' => '',
	'UI-ProblemManagementOverview-ProblemByPriority' => 'Problèmes par priorité',
	'UI-ProblemManagementOverview-ProblemByPriority+' => '',
	'UI-ProblemManagementOverview-ProblemUnassigned' => 'Problèmes non affectés à un agent',
	'UI-ProblemManagementOverview-ProblemUnassigned+' => '',
	'UI:ProblemMgmtMenuOverview:Title' => 'Tableau de bord de la Gestion des Problèmes',
	'UI:ProblemMgmtMenuOverview:Title+' => 'Tableau de bord de la Gestion des Problèmes',

));
//
// Class: Problem
//

Dict::Add('FR FR', 'French', 'Français', array(
	'Class:Problem' => 'Problème',
	'Class:Problem+' => '',
	'Class:Problem/Attribute:status' => 'Etat',
	'Class:Problem/Attribute:status+' => '',
	'Class:Problem/Attribute:status/Value:new' => 'Nouveau',
	'Class:Problem/Attribute:status/Value:new+' => '',
	'Class:Problem/Attribute:status/Value:assigned' => 'Assigné',
	'Class:Problem/Attribute:status/Value:assigned+' => '',
	'Class:Problem/Attribute:status/Value:resolved' => 'Résolu',
	'Class:Problem/Attribute:status/Value:resolved+' => '',
	'Class:Problem/Attribute:status/Value:closed' => 'Fermé',
	'Class:Problem/Attribute:status/Value:closed+' => '',
	'Class:Problem/Attribute:service_id' => 'Service',
	'Class:Problem/Attribute:service_id+' => '',
	'Class:Problem/Attribute:service_name' => 'Nom du service',
	'Class:Problem/Attribute:service_name+' => '',
	'Class:Problem/Attribute:servicesubcategory_id' => 'Sous catégorie de service',
	'Class:Problem/Attribute:servicesubcategory_id+' => '',
	'Class:Problem/Attribute:servicesubcategory_name' => 'Nom sous catégorie de service',
	'Class:Problem/Attribute:servicesubcategory_name+' => '',
	'Class:Problem/Attribute:product' => 'Produit',
	'Class:Problem/Attribute:product+' => '',
	'Class:Problem/Attribute:impact' => 'Impact',
	'Class:Problem/Attribute:impact+' => 'Impact indique la séverité du problème, souvent estimé par le nombre de personnes impactées',
	'Class:Problem/Attribute:impact/Value:1' => 'Un département',
	'Class:Problem/Attribute:impact/Value:1+' => '',
	'Class:Problem/Attribute:impact/Value:2' => 'Un service',
	'Class:Problem/Attribute:impact/Value:2+' => '',
	'Class:Problem/Attribute:impact/Value:3' => 'Une personne',
	'Class:Problem/Attribute:impact/Value:3+' => '',
	'Class:Problem/Attribute:urgency' => 'Urgence',
	'Class:Problem/Attribute:urgency+' => 'Avec quelle célérité le probléme doit être traité',
	'Class:Problem/Attribute:urgency/Value:1' => 'Critique',
	'Class:Problem/Attribute:urgency/Value:1+' => '',
	'Class:Problem/Attribute:urgency/Value:2' => 'Haute',
	'Class:Problem/Attribute:urgency/Value:2+' => '',
	'Class:Problem/Attribute:urgency/Value:3' => 'Moyenne',
	'Class:Problem/Attribute:urgency/Value:3+' => '',
	'Class:Problem/Attribute:urgency/Value:4' => 'Basse',
	'Class:Problem/Attribute:urgency/Value:4+' => '',
	'Class:Problem/Attribute:priority' => 'Priorité',
	'Class:Problem/Attribute:priority+' => 'Ordre dans lequel les problèmes doivent être traités',
	'Class:Problem/Attribute:priority/Value:1' => 'Critique',
	'Class:Problem/Attribute:priority/Value:1+' => '',
	'Class:Problem/Attribute:priority/Value:2' => 'Haute',
	'Class:Problem/Attribute:priority/Value:2+' => '',
	'Class:Problem/Attribute:priority/Value:3' => 'Moyenne',
	'Class:Problem/Attribute:priority/Value:3+' => '',
	'Class:Problem/Attribute:priority/Value:4' => 'Basse',
	'Class:Problem/Attribute:priority/Value:4+' => '',
	'Class:Problem/Attribute:related_change_id' => 'Changement relatif',
	'Class:Problem/Attribute:related_change_id+' => '',
	'Class:Problem/Attribute:related_change_ref' => 'Ref Changement relatif',
	'Class:Problem/Attribute:related_change_ref+' => '',
	'Class:Problem/Attribute:assignment_date' => 'Date d\'assignation',
	'Class:Problem/Attribute:assignment_date+' => '',
	'Class:Problem/Attribute:resolution_date' => 'Date de résolution',
	'Class:Problem/Attribute:resolution_date+' => '',
	'Class:Problem/Attribute:knownerrors_list' => 'Erreurs connues',
	'Class:Problem/Attribute:knownerrors_list+' => 'Toutes les erreurs connues liées à ce problème',
	'Class:Problem/Attribute:knownerrors_list/UI:Links:Create:Button+' => 'Créer une %4$s',
	'Class:Problem/Attribute:knownerrors_list/UI:Links:Create:Modal:Title' => 'Ajouter une %4$s à %2$s',
	'Class:Problem/Attribute:knownerrors_list/UI:Links:Delete:Button+' => 'Supprimer cette %4$s',
	'Class:Problem/Attribute:knownerrors_list/UI:Links:Delete:Modal:Title' => 'Supprimer une %4$s',
	'Class:Problem/Attribute:knownerrors_list/UI:Links:Remove:Button+' => 'Retirer cette %4$s',
	'Class:Problem/Attribute:knownerrors_list/UI:Links:Remove:Modal:Title' => 'Retirer cette %4$s de son %1$s',
	'Class:Problem/Attribute:related_request_list' => 'Requêtes liées',
	'Class:Problem/Attribute:related_request_list+' => 'Toutes les requêtes liées à ce problème',
	'Class:Problem/Attribute:related_request_list/UI:Links:Create:Button+' => 'Créer une %4$s',
	'Class:Problem/Attribute:related_request_list/UI:Links:Create:Modal:Title' => 'Ajouter une %4$s à %2$s',
	'Class:Problem/Attribute:related_request_list/UI:Links:Delete:Button+' => 'Supprimer cette %4$s',
	'Class:Problem/Attribute:related_request_list/UI:Links:Delete:Modal:Title' => 'Supprimer une %4$s',
	'Class:Problem/Attribute:related_request_list/UI:Links:Remove:Button+' => 'Retirer cette %4$s',
	'Class:Problem/Attribute:related_request_list/UI:Links:Remove:Modal:Title' => 'Retirer cette %4$s de son %1$s',
	'Class:Problem/Attribute:related_incident_list' => 'Incidents liés',
	'Class:Problem/Attribute:related_incident_list+' => 'Tous les incidents liés à ce problème',
	'Class:Problem/Attribute:related_incident_list/UI:Links:Create:Button+' => 'Créer un %4$s',
	'Class:Problem/Attribute:related_incident_list/UI:Links:Create:Modal:Title' => 'Ajouter un %4$s à %2$s',
	'Class:Problem/Attribute:related_incident_list/UI:Links:Delete:Button+' => 'Supprimer ce %4$s',
	'Class:Problem/Attribute:related_incident_list/UI:Links:Delete:Modal:Title' => 'Supprimer un %4$s',
	'Class:Problem/Attribute:related_incident_list/UI:Links:Remove:Button+' => 'Retirer ce %4$s',
	'Class:Problem/Attribute:related_incident_list/UI:Links:Remove:Modal:Title' => 'Retirer ce %4$s de son %1$s',
	'Class:Problem/Stimulus:ev_assign' => 'Assigner',
	'Class:Problem/Stimulus:ev_assign+' => '',
	'Class:Problem/Stimulus:ev_reassign' => 'Réaassigner',
	'Class:Problem/Stimulus:ev_reassign+' => '',
	'Class:Problem/Stimulus:ev_resolve' => 'Résoudre',
	'Class:Problem/Stimulus:ev_resolve+' => '',
	'Class:Problem/Stimulus:ev_close' => 'Fermer',
	'Class:Problem/Stimulus:ev_close+' => ''
));
